==> visit2.9.0.tar.gz: visit2.9.0/src/visitpy/visit_flow/flow/src/filters/file_ops.py <==
#*****************************************************************************
#
# Copyright (c) 2000 - 2015, Lawrence Livermore National Security, LLC
# Produced at the Lawrence Livermore National Laboratory
# LLNL-CODE-442911
# All rights reserved.
#
# This file is  part of VisIt. For  details, see https://visit.llnl.gov/.  The
# full copyright notice is contained in the file COPYRIGHT located at the root
# of the VisIt distribution or at http://www.llnl.gov/visit/copyright.html.
#
# Redistribution  and  use  in  source  and  binary  forms,  with  or  without
# modification, are permitted provided that the following conditions are met:
#
#  - Redistributions of  source code must  retain the above  copyright notice,
#    this list of conditions and the disclaimer below.
#  - Redistributions in binary form must reproduce the above copyright notice,
#    this  list of  conditions  and  the  disclaimer (as noted below)  in  the
#    documentation and/or other materials provided with the distribution.
#  - Neither the name of  the LLNS/LLNL nor the names of  its contributors may
#    be used to endorse or promote products derived from this software without
#    specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT  HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR  IMPLIED WARRANTIES, INCLUDING,  BUT NOT  LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND  FITNESS FOR A PARTICULAR  PURPOSE
# ARE  DISCLAIMED. IN  NO EVENT  SHALL LAWRENCE  LIVERMORE NATIONAL  SECURITY,
# LLC, THE  U.S.  DEPARTMENT OF  ENERGY  OR  CONTRIBUTORS BE  LIABLE  FOR  ANY
# DIRECT,  INDIRECT,   INCIDENTAL,   SPECIAL,   EXEMPLARY,  OR   CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT  LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR
# SERVICES; LOSS OF  USE, DATA, OR PROFITS; OR  BUSINESS INTERRUPTION) HOWEVER
# CAUSED  AND  ON  ANY  THEORY  OF  LIABILITY,  WHETHER  IN  CONTRACT,  STRICT
# LIABILITY, OR TORT  (INCLUDING NEGLIGENCE OR OTHERWISE)  ARISING IN ANY  WAY
# OUT OF THE  USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#*****************************************************************************
"""
 file: file_ops.py
 author: Cyrus Harrison <cyrush@llnl.gov>
 created: 10/14/2010
 description:
    Provides flow filters that file system commands.

"""

from ..core import Filter, PropertyTree, sexe

def gen_ofname(node):
    p = node.params
    pattern = p.pattern
    offset  = p.offset
    if pattern.find("%") >0:
        ofname = pattern % (node.state_vector.idx + offset)
    else:
        ofname = pattern
    return ofname

class FileName(Filter):
    filter_type    = "file_name"
    input_ports    = []
    default_params = {"pattern":None, "offset":0}
    output_port    = True
    def execute(self):
        return gen_ofname(self)

class FileRename(Filter):
    filter_type    = "file_rename"
    input_ports    = ["in"]
    default_params =  {"pattern":None, "offset":0}
    output_port    = True
    def execute(self):
        ofname = gen_ofname(self)
        cmd = "mv %s %s" % (self.input("in"),ofname)
        sexe(cmd)
        return ofname

class FileCopy(Filter):
    filter_type    = "file_copy"
    input_ports    = ["in"]
    default_params = {"pattern":None, "offset":0}
    output_port    = True
    def execute(self):
        ofname = gen_ofname(self)
        cmd = "cp %s %s" % (self.input("in"),ofname)
        sexe(cmd)
        return ofname


filters = [FileName, FileRename, FileCopy]

==> visit2.10.3.tar.gz: visit2.10.3/src/visitpy/visit_flow/flow/src/filters/file_ops.py <==
#*****************************************************************************
#
# Copyright (c) 2000 - 2015, Lawrence Livermore National Security, LLC
# Produced at the Lawrence Livermore National Laboratory
# LLNL-CODE-442911
# All rights reserved.
#
# This file is  part of VisIt. For  details, see https://visit.llnl.gov/.  The
# full copyright notice is contained in the file COPYRIGHT located at the root
# of the VisIt distribution or at http://www.llnl.gov/visit/copyright.html.
#
# Redistribution  and  use  in  source  and  binary  forms,  with  or  without
# modification, are permitted provided that the following conditions are met:
#
#  - Redistributions of  source code must  retain the above  copyright notice,
#    this list of conditions and the disclaimer below.
#  - Redistributions in binary form must reproduce the above copyright notice,
#    this  list of  conditions  and  the  disclaimer (as noted below)  in  the
#    documentation and/or other materials provided with the distribution.
#  - Neither the name of  the LLNS/LLNL nor the names of  its contributors may
#    be used to endorse or promote products derived from this software without
#    specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT  HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR  IMPLIED WARRANTIES, INCLUDING,  BUT NOT  LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND  FITNESS FOR A PARTICULAR  PURPOSE
# ARE  DISCLAIMED. IN  NO EVENT  SHALL LAWRENCE  LIVERMORE NATIONAL  SECURITY,
# LLC, THE  U.S.  DEPARTMENT OF  ENERGY  OR  CONTRIBUTORS BE  LIABLE  FOR  ANY
# DIRECT,  INDIRECT,   INCIDENTAL,   SPECIAL,   EXEMPLARY,  OR   CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT  LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR
# SERVICES; LOSS OF  USE, DATA, OR PROFITS; OR  BUSINESS INTERRUPTION) HOWEVER
# CAUSED  AND  ON  ANY  THEORY  OF  LIABILITY,  WHETHER  IN  CONTRACT,  STRICT
# LIABILITY, OR TORT  (INCLUDING NEGLIGENCE OR OTHERWISE)  ARISING IN ANY  WAY
# OUT OF THE  USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#*****************************************************************************
"""
 file: file_ops.py
 author: Cyrus Harrison <cyrush@llnl.gov>
 created: 10/14/2010
 description:
    Provides flow filters that file system commands.

"""

from ..core import Filter, PropertyTree, sexe

def gen_ofname(node):
    p = node.params
    pattern = p.pattern
    offset  = p.offset
    if pattern.find("%") >0:
        ofname = pattern % (node.state_vector.index() + offset)
    else:
        ofname = pattern
    return ofname

class FileName(Filter):
    filter_type    = "file_name"
    input_ports    = []
    default_params = {"pattern":None, "offset":0}
    output_port    = True
    def execute(self):
        return gen_ofname(self)

class FileRename(Filter):
    filter_type    = "file_rename"
    input_ports    = ["in"]
    default_params =  {"pattern":None, "offset":0}
    output_port    = True
    def execute(self):
        ofname = gen_ofname(self)
        cmd = "mv %s %s" % (self.input("in"),ofname)
        sexe(cmd)
        return ofname

class FileCopy(Filter):
    filter_type    = "file_copy"
    input_ports    = ["in"]
    default_params = {"pattern":None, "offset":0}
    output_port    = True
    def execute(self):
        ofname = gen_ofname(self)
        cmd = "cp %s %s" % (self.input("in"),ofname)
        sexe(cmd)
        return ofname


filters = [FileName, FileRename, FileCopy]
